const IdehPayamClientApi = function(username, password) {
    this.restUrl = 'http://localhost:8800/idehpayam/new-api/rest.php';
    this.soapUrl = 'http://localhost:8800/idehpayam/new-api/soap.php?WSDL';
    this.ServiceType = Object.freeze({"SOAP": 1, "REST": 2});
    this.username = username;
    this.password = password;

    this.getUserCredit = async (type = this.ServiceType.SOAP) => {
        switch (type) {
            case this.ServiceType.REST:
                const response = await fetch(this.restUrl, {
                    method: 'POST',
                    body: JSON.stringify({ operation: "GetUserCredit", username: this.username, password: this.password }),
                    headers: { 'Content-Type': 'application/json' }
                });
                const jsonResponse = await response.json();
                if (!jsonResponse) {
                    console.log("Response is not json");
                    return 0;
                }
                const status = jsonResponse.status;
                if (!status) {
                    console.log("Response has not status key");
                    return 0;
                }
                const innerStatus = jsonResponse.result.status;
                if (innerStatus == 0) {
                    return jsonResponse.result.value;
                } else {
                    console.log("Response has invalid satus code: " + innerStatus);
                    return 0;
                }
            break;
            case this.ServiceType.SOAP:
                const soapResponse = await fetch(this.soapUrl, {
                    method: 'POST',
                    body:
                        '<soapenv:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/" xmlns:ideh="idehpayam-api">' +
                            '<soapenv:Header/>' +
                            '<soapenv:Body>' +
                            '<ideh:GetUserCredit soapenv:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">' +
                                '<username xsi:type="xsd:string">' + this.username + '</username>' +
                                '<password xsi:type="xsd:string">' + this.password + '</password>' +
                            '</ideh:GetUserCredit>' +
                            '</soapenv:Body>' +
                        '</soapenv:Envelope>',
                    headers: { 'Content-Type': 'text/xml; charset=UTF-8', 'SOAPAction': 'GetUserCredit' }
                });
                const responseText = await soapResponse.text();
                // console.log(responseText);
                const responseData = (new window.DOMParser()).parseFromString(responseText, "text/xml");
                const getUserCreditResponse = responseData.getElementsByTagName("ns1:GetUserCreditResponse");
                if (getUserCreditResponse.length == 0) {
                    console.log("No GetUserCreditResponse element in response");
                    return 0;
                }
                const returnElm = getUserCreditResponse[0].getElementsByTagName("return");
                if (returnElm.length == 0) {
                    console.log("No return element in response");
                    return 0;
                }
                const statusValue = returnElm[0].getElementsByTagName("status")[0].textContent;
                if (statusValue == "0") {
                    return returnElm[0].getElementsByTagName("value")[0].textContent;
                } else {
                    console.log("Server status code " + statusValue + " returned.");
                    return 0;
                }
            break;
            default:
                console.log('This type of request has not defined.');
            break;
        }
    }
}

var client = new IdehPayamClientApi("prodo", "123456");
client.getUserCredit(client.ServiceType.SOAP).then((value) => {
    console.log("credit: " + value);
});
